type LazyErrorOf<T, I> = <Context<Pallet<T, I>> as VirtualError<LazyBalanceError>>::Error;Expand description
Convenient alias for the error type resolved from the lazy balance context.
type LazyErrorOf<T, I> = <Context<Pallet<T, I>> as VirtualError<LazyBalanceError>>::Error;Convenient alias for the error type resolved from the lazy balance context.