type LazyIdOf<T, I> = <Pallet<T, I> as LazyBalance>::Id;Expand description
Convenient alias for the digest identifier used in lazy balance.
type LazyIdOf<T, I> = <Pallet<T, I> as LazyBalance>::Id;Convenient alias for the digest identifier used in lazy balance.